@@ -36,7 +36,6 @@ import javax.jms.TopicPublisher;
 
 import org.apache.activemq.artemis.api.core.ActiveMQException;
 import org.apache.activemq.artemis.api.core.ActiveMQInterruptedException;
-import org.apache.activemq.artemis.api.core.ActiveMQQueueExistsException;
 import org.apache.activemq.artemis.api.core.SimpleString;
 import org.apache.activemq.artemis.api.core.client.ClientMessage;
 import org.apache.activemq.artemis.api.core.client.ClientProducer;
@@ -45,12 +44,15 @@ import org.apache.activemq.artemis.api.core.client.SendAcknowledgementHandler;
 import org.apache.activemq.artemis.api.core.RoutingType;
 import org.apache.activemq.artemis.utils.UUID;
 import org.apache.activemq.artemis.utils.UUIDGenerator;
+import org.jboss.logging.Logger;
 
 /**
  * ActiveMQ Artemis implementation of a JMS MessageProducer.
  */
 public class ActiveMQMessageProducer implements MessageProducer, QueueSender, TopicPublisher {
 
+   private static final Logger logger = Logger.getLogger(ActiveMQMessageProducer.class);
+
    private final ConnectionFactoryOptions options;
 
    private final ActiveMQConnection connection;
@@ -58,7 +60,7 @@ public class ActiveMQMessageProducer implements MessageProducer, QueueSender, To
    private final SimpleString connID;
 
    private final ClientProducer clientProducer;
-   private final ClientSession clientSession;
+   private final ActiveMQSession session;
 
    private boolean disableMessageID = false;
 
@@ -70,12 +72,11 @@ public class ActiveMQMessageProducer implements MessageProducer, QueueSender, To
    private long defaultDeliveryDelay = Message.DEFAULT_DELIVERY_DELAY;
 
    private final ActiveMQDestination defaultDestination;
-   // Constructors --------------------------------------------------
 
    protected ActiveMQMessageProducer(final ActiveMQConnection connection,
                                      final ClientProducer producer,
                                      final ActiveMQDestination defaultDestination,
-                                     final ClientSession clientSession,
+                                     final ActiveMQSession session,
                                      final ConnectionFactoryOptions options) throws JMSException {
       this.options = options;
       this.connection = connection;
@@ -86,7 +87,7 @@ public class ActiveMQMessageProducer implements MessageProducer, QueueSender, To
 
       this.defaultDestination = defaultDestination;
 
-      this.clientSession = clientSession;
+      this.session = session;
    }
 
    // MessageProducer implementation --------------------------------
@@ -324,7 +325,6 @@ public class ActiveMQMessageProducer implements MessageProducer, QueueSender, To
       return (Queue) getDestination();
    }
 
-   // Public --------------------------------------------------------
 
    @Override
    public String toString() {
@@ -385,6 +385,7 @@ public class ActiveMQMessageProducer implements MessageProducer, QueueSender, To
       }
 
       SimpleString address = null;
+      ClientSession clientSession = session.getCoreSession();
 
       if (destination == null) {
          if (defaultDestination == null) {
@@ -392,42 +393,16 @@ public class ActiveMQMessageProducer implements MessageProducer, QueueSender, To
          }
 
          destination = defaultDestination;
+         // address is meant to be null on this case, as it will use the coreProducer's default address
       } else {
-         if (defaultDestination != null) {
-            if (!destination.equals(defaultDestination)) {
-               throw new UnsupportedOperationException("Where a default destination is specified " + "for the sender and a destination is " + "specified in the arguments to the send, " + "these destinations must be equal");
-            }
+         if (defaultDestination != null && !destination.equals(defaultDestination)) {
+            // This is a JMS TCK & Rule Definition.
+            // if you specified a destination on the Producer, you cannot use it for a different destinations.
+            throw new UnsupportedOperationException("Where a default destination is specified " + "for the sender and a destination is " + "specified in the arguments to the send, " + "these destinations must be equal");
          }
 
+         session.checkDestination(destination);
          address = destination.getSimpleAddress();
-
-         if (!connection.containsKnownDestination(address)) {
-            try {
-               ClientSession.AddressQuery query = clientSession.addressQuery(address);
-
-               if (!query.isExists()) {
-                  if (destination.isQueue() && query.isAutoCreateQueues()) {
-                     clientSession.createAddress(address, RoutingType.ANYCAST, true);
-                     if (destination.isTemporary()) {
-                        // TODO is it right to use the address for the queue name here?
-                        clientSession.createTemporaryQueue(address, RoutingType.ANYCAST, address);
-                     } else {
-                        clientSession.createQueue(address, RoutingType.ANYCAST, address, null, true, true, query.getDefaultMaxConsumers(), query.isDefaultPurgeOnNoConsumers());
-                     }
-                  } else if (!destination.isQueue() && query.isAutoCreateAddresses()) {
-                     clientSession.createAddress(address, RoutingType.MULTICAST, true);
-                  } else if ((destination.isQueue() && !query.isAutoCreateQueues()) || (!destination.isQueue() && !query.isAutoCreateAddresses())) {
-                     throw new InvalidDestinationException("Destination " + address + " does not exist");
-                  }
-               } else {
-                  connection.addKnownDestination(address);
-               }
-            } catch (ActiveMQQueueExistsException e) {
-               // The queue was created by another client/admin between the query check and send create queue packet
-            } catch (ActiveMQException e) {
-               throw JMSExceptionHelper.convertFromActiveMQException(e);
-            }
-         }
       }
 
       ActiveMQMessage activeMQJmsMessage;
@@ -438,7 +413,6 @@ public class ActiveMQMessageProducer implements MessageProducer, QueueSender, To
       if (!(jmsMessage instanceof ActiveMQMessage)) {
          // JMS 1.1 Sect. 3.11.4: A provider must be prepared to accept, from a client,
          // a message whose implementation is not one of its own.
-
          if (jmsMessage instanceof BytesMessage) {
             activeMQJmsMessage = new ActiveMQBytesMessage((BytesMessage) jmsMessage, clientSession);
          } else if (jmsMessage instanceof MapMessage) {
@@ -494,8 +468,7 @@ public class ActiveMQMessageProducer implements MessageProducer, QueueSender, To
       ClientMessage coreMessage = activeMQJmsMessage.getCoreMessage();
       coreMessage.putStringProperty(ActiveMQConnection.CONNECTION_ID_PROPERTY_NAME, connID);
 
-      byte routingType = destination.isQueue() ? RoutingType.ANYCAST.getType() : RoutingType.MULTICAST.getType();
-      coreMessage.putByteProperty(org.apache.activemq.artemis.api.core.Message.HDR_ROUTING_TYPE, routingType);
+      coreMessage.setRoutingType(destination.isQueue() ? RoutingType.ANYCAST : RoutingType.MULTICAST);
 
       try {
          /**
@@ -522,11 +495,13 @@ public class ActiveMQMessageProducer implements MessageProducer, QueueSender, To
    }
 
    private void checkClosed() throws JMSException {
-      if (clientProducer.isClosed() || clientSession.isClosed()) {
+      if (clientProducer.isClosed()) {
          throw new IllegalStateException("Producer is closed");
       }
+      session.checkClosed();
    }
 
+
    private static final class CompletionListenerWrapper implements SendAcknowledgementHandler {
 
       private final CompletionListener completionListener;
@@ -547,6 +522,31 @@ public class ActiveMQMessageProducer implements MessageProducer, QueueSender, To
 
       @Override
       public void sendAcknowledged(org.apache.activemq.artemis.api.core.Message clientMessage) {
+         if (jmsMessage instanceof StreamMessage) {
+            try {
+               ((StreamMessage) jmsMessage).reset();
+            } catch (JMSException e) {
+               logger.debug("ignoring exception", e);
+            }
+         }
+         if (jmsMessage instanceof BytesMessage) {
+            try {
+               ((BytesMessage) jmsMessage).reset();
+            } catch (JMSException e) {
+               logger.debug("ignoring exception", e);
+            }
+         }
+
+         try {
+            producer.connection.getThreadAwareContext().setCurrentThread(true);
+            completionListener.onCompletion(jmsMessage);
+         } finally {
+            producer.connection.getThreadAwareContext().clearCurrentThread(true);
+         }
+      }
+
+      @Override
+      public void sendFailed(org.apache.activemq.artemis.api.core.Message clientMessage, Exception exception) {
          if (jmsMessage instanceof StreamMessage) {
             try {
                ((StreamMessage) jmsMessage).reset();
@@ -564,7 +564,12 @@ public class ActiveMQMessageProducer implements MessageProducer, QueueSender, To
 
          try {
             producer.connection.getThreadAwareContext().setCurrentThread(true);
-            completionListener.onCompletion(jmsMessage);
+            if (exception instanceof ActiveMQException) {
+               exception = JMSExceptionHelper.convertFromActiveMQException((ActiveMQException) exception);
+            } else if (exception instanceof ActiveMQInterruptedException) {
+               exception = JMSExceptionHelper.convertFromActiveMQException((ActiveMQInterruptedException) exception);
+            }
+            completionListener.onException(jmsMessage, exception);
          } finally {
             producer.connection.getThreadAwareContext().clearCurrentThread(true);
          }
